% 
% COMPUTER INTEGRATED SURGERY, 600.446, Group 4
% Quantitative Assessment of Metal Artifact Reduction in C-arm Cone-Beam CT
% Guidance of Neurovascular Interventions
%
% SCRIPT plastic_contrast_coils_04-05.m : calculates the CNR and CT number
% error in an acrylic plastic sphere and polypropylene plastic rod near the aneurysm
% in the second constructed brain phantom.  Analysis is run on both the uncorrected 
% and MAR corrected images in both noncontrast water solution and contrast 
% enhanced iodine solution for each.
% 
% 
% Authors: Marta Wells <mwells20@jhu.edu> 
%          Carolina Cay-Martinez <ccaymar1@jhu.edu>
%          
% 
% Johns Hopkins University
% May 2013
%
%------------------------------------------------------------------------


clear all

fdmar = ['C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[CORRECTED]_MAR_RECONST_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0001';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[CORRECTED]_MAR_RECONST_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0002';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[CORRECTED]_MAR_RECONST_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0010';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[CORRECTED]_MAR_RECONST_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0009';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[CORRECTED]_MAR_RECONST_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0012';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[CORRECTED]_MAR_RECONST_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0013'];

fdnon = ['C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[UNCORRECTED]_MAR_RECON_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0001';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[UNCORRECTED]_MAR_RECON_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0002'
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[UNCORRECTED]_MAR_RECON_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0010';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[UNCORRECTED]_MAR_RECON_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0009';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[UNCORRECTED]_MAR_RECON_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0012';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[UNCORRECTED]_MAR_RECON_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0013'];

%% 1 - Water control
%% 2 - Contrast control
%% 10 - 3 coils with water
%% 9 - 3 coils with contrast
%% 12 - 3 coils with water and stent removed
%% 13 - 3 coils with contrast and stent removed

expectedcenter = [127.42,127.42,-98.44,-98.44;77.35,77.35,-150.07,-150.07];    %%% Acrylic, Polypropylene

num = length(fdmar(:,1));

ucentertot = zeros(4,num);
stdcentertot = zeros(4,num);
ubkgtot = zeros(4,num);
stdbkgtot = zeros(4,num);
stdbkgerr = zeros(4,num);
[yy xx] = meshgrid(1:512);

%%% A = lower plastic sphere
%%% B = upper plastic rod

centera = [323,280;323,280;300,284;300,284;300,284;300,284;];
centerb = [259,285;259,285;236,290;236,290;236,290;236,290;];

findex = [153,153,168,168,168,168];
depth = 10;
halfrange = 5;
maskrad = [20,55];  %%% pixel area = 1467

th = linspace(pi/2,-pi/2,100);

for i  = 1:num
    ucentertemp = zeros(4,depth);
    stdcentertemp = zeros(4,depth);
    ubkgtemp = zeros(4,depth);
    stdbkgtemp = zeros(4,depth);
    
    center = [centera(i,:);centerb(i,:)];
    
    bkgmask1a = sqrt((xx-center(1,1)).^2+(yy-center(1,2)).^2)<=maskrad(2);
    bkgmask2a = sqrt((xx-center(1,1)).^2+(yy-center(1,2)).^2)<=maskrad(1);
    bkgmaska = logical(bkgmask1a - bkgmask2a);
    bkgmaska(:,1:center(1,2)) = 0;
    bkgmaska(1:center(1,1)-20,:) = 0;
    bkgmaska(center(1,1)+20:end,:) = 0;

    bkgmask1b = sqrt((xx-center(2,1)).^2+(yy-center(2,2)).^2)<=maskrad(2);
    bkgmask2b = sqrt((xx-center(2,1)).^2+(yy-center(2,2)).^2)<=maskrad(1);
    bkgmaskb = logical(bkgmask1b - bkgmask2b);
    bkgmaskb(:,1:center(2,2)) = 0;
    bkgmaskb(1:center(2,1)-20,:) = 0;
    bkgmaskb(center(2,1)+20:end,:) = 0;
        
    for j = 1:depth%-1:depth
        cd(char(fdmar(i,:)));
        ss = ls;
        mar{j} = int16(dicomread(char(ss(findex(i)+1+j,:))))-1024;
        cd(char(fdnon(i,:)));
        tt = ls;
        non{j} = int16(dicomread(char(tt(findex(i)+1+j,:))))-1024;
        roimara{j} = mar{j}(center(1,1)-halfrange:center(1,1)+halfrange,center(1,2)-halfrange:center(1,2)+halfrange);
        roinona{j} = non{j}(center(1,1)-halfrange:center(1,1)+halfrange,center(1,2)-halfrange:center(1,2)+halfrange);

%         figure; %%%Plot MAR
%         imshow(mar{j},'DisplayRange',[-1024 4500-1024])
%         colorbar
%         hold on
%         rectangle('Position',[center(1,2)-halfrange(1,1),center(1,1)-halfrange(1,1),halfrange(1,1)*2,halfrange(1,1)*2],'EdgeColor','r')
%         x = maskrad(1)*cos(th) + center(1,2);
%         y = maskrad(1)*sin(th) + center(1,1);
%         plot(x,y,'y'); axis equal;
%         x = maskrad(2)*cos(th) + center(1,2);
%         y = maskrad(2)*sin(th) + center(1,1);
%         x = x(39:62);
%         y = y(39:62);
%         plot(x,y,'y'); axis equal;
%         x = (center(1,1)+20)*ones(52,1);
%         y = center(1,2):center(1,2)+51;
%         plot(y,x,'y'); axis equal;
%         x = (center(1,1)-20)*ones(52,1);
%         y = center(1,2):center(1,2)+51;
%         plot(y,x,'y'); axis equal;
%         
%         figure; %%%Plot UC
%         imshow(non{j},'DisplayRange',[-1024 4500-1024])
%         colorbar
%         hold on
%         rectangle('Position',[center(1,2)-halfrange(1,1),center(1,1)-halfrange(1,1),halfrange(1,1)*2,halfrange(1,1)*2],'EdgeColor','r')
%         x = maskrad(1)*cos(th) + center(1,2);
%         y = maskrad(1)*sin(th) + center(1,1);
%         plot(x,y,'y'); axis equal;
%         x = maskrad(2)*cos(th) + center(1,2);
%         y = maskrad(2)*sin(th) + center(1,1);
%         x = x(39:62);
%         y = y(39:62);
%         plot(x,y,'y'); axis equal;
%         x = (center(1,1)+20)*ones(52,1);
%         y = center(1,2):center(1,2)+51;
%         plot(y,x,'y'); axis equal;
%         x = (center(1,1)-20)*ones(52,1);
%         y = center(1,2):center(1,2)+51;
%         plot(y,x,'y'); axis equal;
        
        ucentertemp(1,j) = mean2(roimara{j});
        ucentertemp(2,j) = mean2(roinona{j});
        stdcentertemp(1,j) = std2(roimara{j});
        stdcentertemp(2,j) = std2(roinona{j});
        ubkgtemp(1,j) = mean(mar{j}(bkgmaska));
        ubkgtemp(2,j) = mean(non{j}(bkgmaska));
        stdbkgtemp(1,j) = std2(mar{j}(bkgmaska));
        stdbkgtemp(2,j) = std2(non{j}(bkgmaska));
    end
    
    for k = 1:depth%-1:depth
        cd(char(fdmar(i,:)));
        ss = ls;
        mar{k} = int16(dicomread(char(ss(findex(i)+1+k,:))))-1024;
        cd(char(fdnon(i,:)));
        tt = ls;
        non{k} = int16(dicomread(char(tt(findex(i)+1+k,:))))-1024;
        roimarb{k} = mar{k}(center(2,1)-halfrange:center(2,1)+halfrange,center(2,2)-halfrange:center(2,2)+halfrange);
        roinonb{k} = non{k}(center(2,1)-halfrange:center(2,1)+halfrange,center(2,2)-halfrange:center(2,2)+halfrange);
        
%         figure;
%         imshow(mar{k}, 'DisplayRange',[-1024 4500-1024])
%         colorbar
%         hold on
%         rectangle('Position',[center(2,2)-halfrange(1,1),center(2,1)-halfrange(1,1),halfrange(1,1)*2,halfrange(1,1)*2],'EdgeColor','r')
%         x = maskrad(1)*cos(th) + center(2,2);
%         y = maskrad(1)*sin(th) + center(2,1);
%         plot(x,y,'y'); axis equal;
%         x = maskrad(2)*cos(th) + center(2,2);
%         y = maskrad(2)*sin(th) + center(2,1);
%         x = x(39:62);
%         y = y(39:62);
%         plot(x,y,'y'); axis equal;
%         x = (center(2,1)+20)*ones(52,1);
%         y = center(2,2):center(2,2)+51;
%         plot(y,x,'y'); axis equal;
%         x = (center(2,1)-20)*ones(52,1);
%         y = center(2,2):center(2,2)+51;
%         plot(y,x,'y'); axis equal;
%         
%         figure;
%         imshow(non{k}, 'DisplayRange',[-1024 4500-1024])
%         colorbar
%         hold on
%         rectangle('Position',[center(2,2)-halfrange(1,1),center(2,1)-halfrange(1,1),halfrange(1,1)*2,halfrange(1,1)*2],'EdgeColor','r')
%         x = maskrad(1)*cos(th) + center(2,2);
%         y = maskrad(1)*sin(th) + center(2,1);
%         plot(x,y,'y'); axis equal;
%         x = maskrad(2)*cos(th) + center(2,2);
%         y = maskrad(2)*sin(th) + center(2,1);
%         x = x(39:62);
%         y = y(39:62);
%         plot(x,y,'y'); axis equal;
%         x = (center(2,1)+20)*ones(52,1);
%         y = center(2,2):center(2,2)+51;
%         plot(y,x,'y'); axis equal;
%         x = (center(2,1)-20)*ones(52,1);
%         y = center(2,2):center(2,2)+51;
%         plot(y,x,'y'); axis equal;
%         
        ucentertemp(3,k) = mean2(roimarb{k});
        ucentertemp(4,k) = mean2(roinonb{k});
        stdcentertemp(3,k) = std2(roimarb{k});
        stdcentertemp(4,k) = std2(roinonb{k});
        ubkgtemp(3,k) = mean(mar{k}(bkgmaskb));
        ubkgtemp(4,k) = mean(non{k}(bkgmaskb));
        stdbkgtemp(3,k) = std2(mar{k}(bkgmaskb));
        stdbkgtemp(4,k) = std2(non{k}(bkgmaskb));
    end

    ucentertot(:,i) = mean(ucentertemp,2);
    stdcentertot(:,i) = mean(stdcentertemp,2);
    ubkgtot(:,i) = mean(ubkgtemp,2);
    stdbkgtot(:,i) = mean(stdbkgtemp,2);
    stdbkgerr(:,i) = std(stdbkgtemp,0,2);
    
    
    if (i == 1 || i == 3 || i == 5)
        contrasterr(:,i) = 100*abs((ucentertot(:,i) - expectedcenter(1,:)')./expectedcenter(1,:)');
    else
        contrasterr(:,i) = 100*abs((ucentertot(:,i) - expectedcenter(2,:)')./expectedcenter(2,:)');
    end

    
end

cnr = abs(ucentertot - ubkgtot)./stdbkgtot;

cd ../../























