% 
% COMPUTER INTEGRATED SURGERY, 600.446, Group 4
% Quantitative Assessment of Metal Artifact Reduction in C-arm Cone-Beam CT
% Guidance of Neurovascular Interventions
%
% SCRIPT plastic_contrast_onyx.m : calculates the CNR and CT number
% error in an acrylic plastic sphere and polypropylene plastic rod near the aneurysm
% in the third constructed brain phantom.  Analysis is run on both the uncorrected 
% and MAR corrected images in both noncontrast water solution and contrast 
% enhanced iodine solution for each.
% 
% 
% Authors: Marta Wells <mwells20@jhu.edu> 
%          Carolina Cay-Martinez <ccaymar1@jhu.edu>
%          
% 
% Johns Hopkins University
% May 2013
%
%------------------------------------------------------------------------

clear all

fdmar = [cellstr('C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\onyx\DYNACT_HEAD_NAT_FILL_HU_NORMAL_[INSPACE3D]_0001');
    cellstr('C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\onyx\DYNACT_HEAD_NAT_FILL_HU_NORMAL_[INSPACE3D]_0002');
    cellstr('C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\onyx\MAR\MAR_[CORRECTED]_NON-TRUNC_NAT_FILL_HU_NORMAL_[NO_CLINICAL_U_0014');  
    cellstr('C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\onyx\MAR\MAR_[CORRECTED]_NON-TRUNC_NAT_FILL_HU_NORMAL_[NO_CLINICAL_U_0012')];

fdnon = [cellstr('C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\onyx\DYNACT_HEAD_NAT_FILL_HU_NORMAL_[INSPACE3D]_0001');
    cellstr('C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\onyx\DYNACT_HEAD_NAT_FILL_HU_NORMAL_[INSPACE3D]_0002');
    cellstr('C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\onyx\MAR\MAR_[UNCORRECTED]_NON-TRUNC_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0014'); 
    cellstr('C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\onyx\MAR\MAR_[UNCORRECTED]_NON-TRUNC_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0012')];

%%% 1 - Control NC
%%% 2 - Control CE
%%% 14 - Onyx NC
%%% 12 - Onyx CE

expectedcenter = [109.31,109.31,-70.42,-70.42;83.08,83.08,-68.61,-68.61];    %%% Acrylic, Polypropylene

num = length(fdmar(:,1));

ucentertot = zeros(4,num);
stdcentertot = zeros(4,num);
ubkgtot = zeros(4,num);
stdbkgtot = zeros(4,num);
stdbkgerr = zeros(4,num);
[yy xx] = meshgrid(1:512);

%%% A = lower plastic sphere
%%% B = upper plastic rod

centera = [285,273;285,273;288,257;288,257;];
centerb = [215,302;215,302;218,286;218,286;];

findex = [159,159,177,177];
depth = 5;
halfrange = 5;
maskrad = [25,60];  %%% pixel area = 1429

th = linspace(pi/2,-pi/2,100);

for i  = 1:num
    ucentertemp = zeros(4,depth);
    stdcentertemp = zeros(4,depth);
    ubkgtemp = zeros(4,depth);
    stdbkgtemp = zeros(4,depth);
    
    center = [centera(i,:);centerb(i,:)];
    
    bkgmask1a = sqrt((xx-center(1,1)).^2+(yy-center(1,2)).^2)<=maskrad(2);
    bkgmask2a = sqrt((xx-center(1,1)).^2+(yy-center(1,2)).^2)<=maskrad(1);
    bkgmaska = logical(bkgmask1a - bkgmask2a);
    bkgmaska(1:center(1,1),:) = 0;
    bkgmaska(:,1:center(1,2)-20) = 0;
    bkgmaska(:,center(1,2)+20:end) = 0;

    bkgmask1b = sqrt((xx-center(2,1)).^2+(yy-center(2,2)).^2)<=maskrad(2);
    bkgmask2b = sqrt((xx-center(2,1)).^2+(yy-center(2,2)).^2)<=maskrad(1);
    bkgmaskb = logical(bkgmask1b - bkgmask2b);
    bkgmaskb(:,1:center(2,2)) = 0;
    bkgmaskb(1:center(2,1)-20,:) = 0;
    bkgmaskb(center(2,1)+20:end,:) = 0;
        
    for j = 1:depth%-1:depth
        cd(char(fdmar(i,:)));
        ss = ls;
        mar{j} = int16(dicomread(char(ss(findex(i)+1+j,:))))-1024;
        cd(char(fdnon(i,:)));
        tt = ls;
        non{j} = int16(dicomread(char(tt(findex(i)+1+j,:))))-1024;
        roimara{j} = mar{j}(center(1,1)-halfrange:center(1,1)+halfrange,center(1,2)-halfrange:center(1,2)+halfrange);
        roinona{j} = non{j}(center(1,1)-halfrange:center(1,1)+halfrange,center(1,2)-halfrange:center(1,2)+halfrange);

%         figure; %%%Plot MAR
%         th = linspace(0,pi,100);
%         imshow(mar{j},'DisplayRange',[-1024 4500-1024])
%         colorbar
%         hold on
%         rectangle('Position',[center(1,2)-halfrange(1,1),center(1,1)-halfrange(1,1),halfrange(1,1)*2,halfrange(1,1)*2],'EdgeColor','r')
%         x = maskrad(1)*cos(th) + center(1,2);
%         y = maskrad(1)*sin(th) + center(1,1);
%         plot(x,y,'y'); axis equal;
%         x = maskrad(2)*cos(th) + center(1,2);
%         y = maskrad(2)*sin(th) + center(1,1);
%         x = x(37:64);
%         y = y(37:64);
%         plot(x,y,'y'); axis equal;
%         x = (center(1,2)+25)*ones(56,1);
%         y = center(1,1):center(1,1)+55;
%         plot(x,y,'y'); axis equal;
%         x = (center(1,2)-25)*ones(56,1);
%         y = center(1,1):center(1,1)+55;
%         plot(x,y,'y'); axis equal;
%         
%         figure; %%%Plot UC
%         th = linspace(0,pi,100);
%         imshow(non{j},'DisplayRange',[-1024 4500-1024])
%         colorbar
%         hold on
%         rectangle('Position',[center(1,2)-halfrange(1,1),center(1,1)-halfrange(1,1),halfrange(1,1)*2,halfrange(1,1)*2],'EdgeColor','r')
%         x = maskrad(1)*cos(th) + center(1,2);
%         y = maskrad(1)*sin(th) + center(1,1);
%         plot(x,y,'y'); axis equal;
%         x = maskrad(2)*cos(th) + center(1,2);
%         y = maskrad(2)*sin(th) + center(1,1);
%         x = x(37:64);
%         y = y(37:64);
%         plot(x,y,'y'); axis equal;
%         x = (center(1,2)+25)*ones(56,1);
%         y = center(1,1):center(1,1)+55;
%         plot(x,y,'y'); axis equal;
%         x = (center(1,2)-25)*ones(56,1);
%         y = center(1,1):center(1,1)+55;
%         plot(x,y,'y'); axis equal;
%         
        ucentertemp(1,j) = mean2(roimara{j});
        ucentertemp(2,j) = mean2(roinona{j});
        stdcentertemp(1,j) = std2(roimara{j});
        stdcentertemp(2,j) = std2(roinona{j});
        ubkgtemp(1,j) = mean(mar{j}(bkgmaska));
        ubkgtemp(2,j) = mean(non{j}(bkgmaska));
        stdbkgtemp(1,j) = std2(mar{j}(bkgmaska));
        stdbkgtemp(2,j) = std2(non{j}(bkgmaska));
    end
    
    for k = 1:depth%-1:depth
        cd(char(fdmar(i,:)));
        ss = ls;
        mar{k} = int16(dicomread(char(ss(findex(i)+1+k,:))))-1024;
        cd(char(fdnon(i,:)));
        tt = ls;
        non{k} = int16(dicomread(char(tt(findex(i)+1+k,:))))-1024;
        roimarb{k} = mar{k}(center(2,1)-halfrange:center(2,1)+halfrange,center(2,2)-halfrange:center(2,2)+halfrange);
        roinonb{k} = non{k}(center(2,1)-halfrange:center(2,1)+halfrange,center(2,2)-halfrange:center(2,2)+halfrange);
        
%         figure;
%         th = linspace(pi/2,-pi/2,100);
%         imshow(mar{k}, 'DisplayRange',[-1024 4500-1024])
%         colorbar
%         hold on
%         rectangle('Position',[center(2,2)-halfrange(1,1),center(2,1)-halfrange(1,1),halfrange(1,1)*2,halfrange(1,1)*2],'EdgeColor','r')
%         x = maskrad(1)*cos(th) + center(2,2);
%         y = maskrad(1)*sin(th) + center(2,1);
%         plot(x,y,'y'); axis equal;
%         x = maskrad(2)*cos(th) + center(2,2);
%         y = maskrad(2)*sin(th) + center(2,1);
%         x = x(37:64);
%         y = y(37:64);
%         plot(x,y,'y'); axis equal;
%         x = (center(2,1)+25)*ones(56,1);
%         y = center(2,2):center(2,2)+55;
%         plot(y,x,'y'); axis equal;
%         x = (center(2,1)-25)*ones(56,1);
%         y = center(2,2):center(2,2)+55;
%         plot(y,x,'y'); axis equal;
%         
%         figure;
%         th = linspace(pi/2,-pi/2,100);
%         imshow(non{k}, 'DisplayRange',[-1024 4500-1024])
%         colorbar
%         hold on
%         rectangle('Position',[center(2,2)-halfrange(1,1),center(2,1)-halfrange(1,1),halfrange(1,1)*2,halfrange(1,1)*2],'EdgeColor','r')
%         x = maskrad(1)*cos(th) + center(2,2);
%         y = maskrad(1)*sin(th) + center(2,1);
%         plot(x,y,'y'); axis equal;
%         x = maskrad(2)*cos(th) + center(2,2);
%         y = maskrad(2)*sin(th) + center(2,1);
%         x = x(37:64);
%         y = y(37:64);
%         plot(x,y,'y'); axis equal;
%         x = (center(2,1)+25)*ones(56,1);
%         y = center(2,2):center(2,2)+55;
%         plot(y,x,'y'); axis equal;
%         x = (center(2,1)-25)*ones(56,1);
%         y = center(2,2):center(2,2)+55;
%         plot(y,x,'y'); axis equal;
%         
        ucentertemp(3,k) = mean2(roimarb{k});
        ucentertemp(4,k) = mean2(roinonb{k});
        stdcentertemp(3,k) = std2(roimarb{k});
        stdcentertemp(4,k) = std2(roinonb{k});
        ubkgtemp(3,k) = mean(mar{k}(bkgmaskb));
        ubkgtemp(4,k) = mean(non{k}(bkgmaskb));
        stdbkgtemp(3,k) = std2(mar{k}(bkgmaskb));
        stdbkgtemp(4,k) = std2(non{k}(bkgmaskb));
    end

    ucentertot(:,i) = mean(ucentertemp,2);
    stdcentertot(:,i) = mean(stdcentertemp,2);
    ubkgtot(:,i) = mean(ubkgtemp,2);
    stdbkgtot(:,i) = mean(stdbkgtemp,2);
    stdbkgerr(:,i) = std(stdbkgtemp,0,2);
    
    
    if (i == 1 || i == 3)
        contrasterr(:,i) = 100*abs((ucentertot(:,i) - expectedcenter(1,:)')./expectedcenter(1,:)');
    else
        contrasterr(:,i) = 100*abs((ucentertot(:,i) - expectedcenter(2,:)')./expectedcenter(2,:)');
    end

    
end

cnr = abs(ucentertot - ubkgtot)./stdbkgtot;

cd ../










