% 
% COMPUTER INTEGRATED SURGERY, 600.446, Group 4
% Quantitative Assessment of Metal Artifact Reduction in C-arm Cone-Beam CT
% Guidance of Neurovascular Interventions
%
% SCRIPT sigma_artifact_coils_04-05.m : calculates the mean attentuation 
% values of the metal coils, the mean attenutation values of the background
% area surrounding the coils, the standard deviation of the background 
% (artifact magnitude), and the error in the standard deviation in the 
% second constructed brain phantom. Analysis is run on both the uncorrected
% and MAR corrected images in both noncontrast water solution and contrast 
% enhanced iodine solution for each.
%
% 
% Authors: Marta Wells <mwells20@jhu.edu> 
%          Carolina Cay-Martinez <ccaymar1@jhu.edu>
%          
% 
% Johns Hopkins University
% May 2013
%
%------------------------------------------------------------------------

clear all

fdmar = ['C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[CORRECTED]_MAR_RECONST_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0009';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[CORRECTED]_MAR_RECONST_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0010';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[CORRECTED]_MAR_RECONST_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0012';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[CORRECTED]_MAR_RECONST_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0013'];


fdnon = ['C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[UNCORRECTED]_MAR_RECON_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0009';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[UNCORRECTED]_MAR_RECON_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0010';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[UNCORRECTED]_MAR_RECON_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0012';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\MAR\MAR_[UNCORRECTED]_MAR_RECON_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0013'];

num = length(fdmar(:,1));
center = [276,256];
findex = 169;
ucentertot = zeros(2,num);
stdcentertot = zeros(2,num);
ubkgtot = zeros(2,num);
stdbkgtot = zeros(2,num);
stdbkgerr = zeros(2,num);
[yy xx] = meshgrid(1:512);

%% 9 - 3 coils with contrast
%% 10 - 3 coils with water
%% 12 - 3 coils with water and stent removed
%% 13 - 3 coils with contrast and stent removed

for i = 1:num
    ucentertemp = zeros(2,8);
    stdcentertemp = zeros(2,8);
    ubkgtemp = zeros(2,8);
    stdbkgtemp = zeros(2,8);
    
    bkgmask1 = sqrt((xx-center(1)).^2+(yy-center(2)).^2)<=43;
    bkgmask2 = sqrt((xx-center(1)).^2+(yy-center(2)).^2)<=21;
    bkgmask = logical(bkgmask1 - bkgmask2);
    bkgmask(:,center(2)+1:end) = 0;
    bkgmask(1:center(1)-15,:) = 0;   %%% ~1450 pixels 
    
    for j = 1:8
        cd(fdmar(i,:));
        ss = ls;
        mar{j} = int16(dicomread(char(ss(findex+1+j,:))))-1024;
        cd(fdnon(i,:));
        tt = ls;
        non{j} = int16(dicomread(char(tt(findex+1+j,:))))-1024;
        roimar{j} = mar{j}(center(1)-4:center(1)+4,center(2)-4:center(2)+4);
        roinon{j} = non{j}(center(1)-4:center(1)+4,center(2)-4:center(2)+4);
        ucentertemp(1,j) = mean2(roimar{j});
        ucentertemp(2,j) = mean2(roinon{j});
        stdcentertemp(1,j) = std2(roimar{j});
        stdcentertemp(2,j) = std2(roinon{j});
        ubkgtemp(1,j) = mean(mar{j}(bkgmask));
        ubkgtemp(2,j) = mean(non{j}(bkgmask));
        stdbkgtemp(1,j) = std2(mar{j}(bkgmask));
        stdbkgtemp(2,j) = std2(non{j}(bkgmask));
    end

    ucentertot(:,i) = mean(ucentertemp,2);
    stdcentertot(:,i) = mean(stdcentertemp,2);
    ubkgtot(:,i) = mean(ubkgtemp,2);
    stdbkgtot(:,i) = mean(stdbkgtemp,2);
    stdbkgerr(:,i) = std(stdbkgtemp,0,2);
end

cd ../../

% fd = ['C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\DYNACT_HEAD_NAT_FILL_HU_NORMAL_[INSPACE3D]_0006';
%     'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 04-05\__20130405_155629_343000\DYNACT_HEAD_NAT_FILL_HU_NORMAL_[INSPACE3D]_0007'];
% 
% ucenterstent = zeros(2,1);
% stdcenterstent = zeros(2,1);
% ubkgstent = zeros(2,1);
% stdbkgstent = zeros(2,1);
% 
% top = [273,252];
% findex = 180;
% 
% for i = 1:2
%     cd(fd(i,:));
%     ss = ls;
% 
%     %center = centers(i,:);
%     %findex = filest(i,:);
%     
%     bkgmask1 = sqrt((xx-top(1)+5).^2+(yy-top(2)).^2)<=25;
%     bkgmask2 = sqrt((xx-top(1)+5).^2+(yy-top(2)).^2)<=20;
%     bkgmask = logical(bkgmask1 - bkgmask2);
%     
%     stent{i} = dicomread(char(ss(findex+2,:)));
%     roistent{i} = stent{i}(top(1):top(1)+10,top(2):top(2));
%     ucenterstent(i) = mean2(roistent{i});
%     stdcenterstent(i) = std2(roistent{i});
%     ubkgstent(i) = mean(stent{i}(bkgmask));
%     stdbkgstent(i) = std2(stent{i}(bkgmask));
%     
%     
% end
% 
% cd ../
% 

















