% 
% COMPUTER INTEGRATED SURGERY, 600.446, Group 4
% Quantitative Assessment of Metal Artifact Reduction in C-arm Cone-Beam CT
% Guidance of Neurovascular Interventions
%
% SCRIPT sigma_artifact_coils_05-02.m : calculates the standard deviation
% (artifact magnitude) of the background area surrounding the coiled
% aneurysm and the error in the standard deviation in the fourth constructed brain 
% phantom for images with combinations of two metal spheres. Analysis is 
% run on both the uncorrected and MAR corrected images in both noncontrast 
% water solution and contrast enhanced iodine solution for each.
%
% 
% Authors: Marta Wells <mwells20@jhu.edu> 
%          Carolina Cay-Martinez <ccaymar1@jhu.edu>
%          
% 
% Johns Hopkins University
% May 2013
%
%------------------------------------------------------------------------

clear all

fdmar = ['C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 05-02\MAR_[CORRECTED]_NON-TRUNC_NAT_FILL_HU_NORMAL_[NO_CLINICAL_U_0007';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 05-02\MAR_[CORRECTED]_NON-TRUNC_NAT_FILL_HU_NORMAL_[NO_CLINICAL_U_0006';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 05-02\MAR_[CORRECTED]_NON-TRUNC_NAT_FILL_HU_NORMAL_[NO_CLINICAL_U_0008';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 05-02\MAR_[CORRECTED]_NON-TRUNC_NAT_FILL_HU_NORMAL_[NO_CLINICAL_U_0009';];

fdnon = ['C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 05-02\MAR_[UNCORRECTED]_NON-TRUNC_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0007';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 05-02\MAR_[UNCORRECTED]_NON-TRUNC_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0006';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 05-02\MAR_[UNCORRECTED]_NON-TRUNC_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0008';
    'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Coil 05-02\MAR_[UNCORRECTED]_NON-TRUNC_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0009';];

%%% 7 - 2 Coils NC
%%% 6 - 2 Coils CE
%%% 8 - 7 Coils NC
%%% 9 - 7 Coils CE

num = length(fdmar(:,1));
center = [318,268];
findex = [188,188;188,188;188,188;178,188;];
ucentertot = zeros(2,num);
stdcentertot = zeros(2,num);
ubkgtot = zeros(2,num);
stdbkgtot = zeros(2,num);
stdbkgerr = zeros(2,num);
[yy xx] = meshgrid(1:512);

depth = 15;
maskrad = [35,56];
halfrange = 4;

th = linspace(-pi/2,0,100);

for i = 1:num
    
    fid = findex(i,:);
    
    ucentertemp = zeros(2,depth);
    stdcentertemp = zeros(2,depth);
    ubkgtemp = zeros(2,depth);
    stdbkgtemp = zeros(2,depth);
    
    bkgmask1 = sqrt((xx-center(1)).^2+(yy-center(2)).^2)<=maskrad(2);
    bkgmask2 = sqrt((xx-center(1)).^2+(yy-center(2)).^2)<=maskrad(1);
    bkgmask = logical(bkgmask1 - bkgmask2);
    bkgmask(:,1:center(2)+1) = 0;
    bkgmask(1:center(1)+1,:) = 0;   %%% 1435 pixels 
    
    for j = 1:depth
        cd(fdmar(i,:));
        ss = ls;
        mar{j} = int16(dicomread(char(ss(fid(1)+1+j,:))))-1024;
        cd(fdnon(i,:));
        tt = ls;
        non{j} = int16(dicomread(char(tt(fid(2)+1+j,:))))-1024;
        roimar{j} = mar{j}(center(1)-halfrange:center(1)+halfrange,center(2)-halfrange:center(2)+halfrange);
        roinon{j} = non{j}(center(1)-halfrange:center(1)+halfrange,center(2)-halfrange:center(2)+halfrange);
        ucentertemp(1,j) = mean2(roimar{j});
        ucentertemp(2,j) = mean2(roinon{j});
        stdcentertemp(1,j) = std2(roimar{j});
        stdcentertemp(2,j) = std2(roinon{j});
        ubkgtemp(1,j) = mean(mar{j}(bkgmask));
        ubkgtemp(2,j) = mean(non{j}(bkgmask));
        stdbkgtemp(1,j) = std2(mar{j}(bkgmask));
        stdbkgtemp(2,j) = std2(non{j}(bkgmask));
        
%         figure; %%%Plot MAR
%         imshow(mar{j},'DisplayRange',[-250 2000])
%         colorbar;
%         hold on
%         x = maskrad(1)*cos(th) + center(2);
%         y = -maskrad(1)*sin(th) + center(1);
%         plot(x,y,'y'); axis equal;
%         x = maskrad(2)*cos(th) + center(2);
%         y = -maskrad(2)*sin(th) + center(1);
%         plot(x,y,'y'); axis equal;
%         x = center(2)+maskrad(1):center(2)+maskrad(2);
%         y = center(1)*ones(22,1);
%         plot(x,y,'y'); axis equal;
%         y = center(1)+maskrad(1):center(1)+maskrad(2);
%         x = center(2)*ones(22,1);
%         plot(x,y,'y'); axis equal; 
%         
%         figure; %%%Plot UC
%         imshow(non{j},'DisplayRange',[-250 2000])
%         colorbar;
%         hold on
%         x = maskrad(1)*cos(th) + center(2);
%         y = -maskrad(1)*sin(th) + center(1);
%         plot(x,y,'y'); axis equal;
%         x = maskrad(2)*cos(th) + center(2);
%         y = -maskrad(2)*sin(th) + center(1);
%         plot(x,y,'y'); axis equal;
%         x = center(2)+maskrad(1):center(2)+maskrad(2);
%         y = center(1)*ones(22,1);
%         plot(x,y,'y'); axis equal;
%         y = center(1)+maskrad(1):center(1)+maskrad(2);
%         x = center(2)*ones(22,1);
%         plot(x,y,'y'); axis equal; 
        
        
    end

    ucentertot(:,i) = mean(ucentertemp,2);
    stdcentertot(:,i) = mean(stdcentertemp,2);
    ubkgtot(:,i) = mean(ubkgtemp,2);
    stdbkgtot(:,i) = mean(stdbkgtemp,2);
    stdbkgerr(:,i) = std(stdbkgtemp,0,2);
end

cd ../










