% 
% COMPUTER INTEGRATED SURGERY, 600.446, Group 4
% Quantitative Assessment of Metal Artifact Reduction in C-arm Cone-Beam CT
% Guidance of Neurovascular Interventions
%
% SCRIPT sigma_artifact_doubles.m : calculates the standard deviation
% (artifact magnitude) of the background area surrounding the each metal sphere
% and the error in the standard deviation in the first constructed brain 
% phantom for images with combinations of two metal spheres. Analysis is 
% run on both the uncorrected and MAR corrected images.
%
% 
% Authors: Marta Wells <mwells20@jhu.edu> 
%          Carolina Cay-Martinez <ccaymar1@jhu.edu>
%          
% 
% Johns Hopkins University
% May 2013
%
%------------------------------------------------------------------------

clear all

fdmar = ['C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\MARproject\MAR_[CORRECTED]_MAR_RECONST_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0024';  
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\MARproject\MAR_[CORRECTED]_MAR_RECONST_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0026';
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\MARproject\MAR_[CORRECTED]_MAR_RECONST_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0028';];

fdnon = ['C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\MARproject\MAR_[UNCORRECTED]_MAR_RECON_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0024';  
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\MARproject\MAR_[UNCORRECTED]_MAR_RECON_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0026';
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\MARproject\MAR_[UNCORRECTED]_MAR_RECON_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0028';];

%%% 24 - Ti:R & Steel:L
%%% 26 - W:R & Steel:L
%%% 28 - W:R & Ti:L

num = length(fdmar(:,1));

fst = [146,152,155];
depth = [5,3,4];
halfrange = 2;

maskrad = [13,45];

centers = [280,241,289,276;
    282,237,292,274;
    282,244,295,278];

[yy xx] = meshgrid(1:512);

ucentertot = zeros(4,num);
ucentererr = zeros(4,num);
stdcentertot = zeros(4,num);
ubkgtot = zeros(4,num);
ubkgerr = zeros(4,num);
stdbkgtot = zeros(4,num);
stdbkgerr = zeros(4,num);

for i  = 1:num
    
    ucentertemp = zeros(4,depth(i));
    stdcentertemp = zeros(4,depth(i));
    ubkgtemp = zeros(4,depth(i));
    stdbkgtemp = zeros(4,depth(i));
    center = centers(i,:);
    centerL = center(1:2);
    centerR = center(3:4);
    findex = fst(i);
    
    bkgmask1L = sqrt((xx-centerL(1)).^2+(yy-centerL(2)).^2)<=maskrad(2);
    bkgmask2L = sqrt((xx-centerL(1)).^2+(yy-centerL(2)).^2)<=maskrad(1);
    bkgmask1R = sqrt((xx-centerR(1)).^2+(yy-centerR(2)).^2)<=maskrad(2);
    bkgmask2R = sqrt((xx-centerR(1)).^2+(yy-centerR(2)).^2)<=maskrad(1);
    bkgmaskL = logical(bkgmask1L - bkgmask2L);
    bkgmaskR = logical(bkgmask1R - bkgmask2R);
    bkgmaskL(:,centerL(2)+1:end) = 0;
    bkgmaskR(:,1:centerR(2)-1) = 0;
    bkgmaskL(centerL(1)+1:end,:) = 0;
    bkgmaskR(centerR(1)+1:end,:) = 0;
    
    for j = 1:depth(i)
        cd(char(fdmar(i,:)));
        ss = ls;
        mar{j} = int16(dicomread(char(ss(findex+1+j,:))))-1024;
        cd(char(fdnon(i,:)));
        tt = ls;
        non{j} = int16(dicomread(char(tt(findex+1+j,:))))-1024;
        
        roimarL{j} = mar{j}(centerL(1)-halfrange:centerL(1)+halfrange,centerL(2)-halfrange:centerL(2)+halfrange);
        roinonL{j} = non{j}(centerL(1)-halfrange:centerL(1)+halfrange,centerL(2)-halfrange:centerL(2)+halfrange);
        ucentertemp(1,j) = mean2(roimarL{j});
        ucentertemp(2,j) = mean2(roinonL{j});
        stdcentertemp(1,j) = std2(roimarL{j});
        stdcentertemp(2,j) = std2(roinonL{j});
        ubkgtemp(1,j) = mean(mar{j}(bkgmaskL));
        ubkgtemp(2,j) = mean(non{j}(bkgmaskL));
        stdbkgtemp(1,j) = std2(mar{j}(bkgmaskL));
        stdbkgtemp(2,j) = std2(non{j}(bkgmaskL));
        
        roimarR{j} = mar{j}(centerR(1)-halfrange:centerR(1)+halfrange,centerR(2)-halfrange:centerR(2)+halfrange);
        roinonR{j} = non{j}(centerR(1)-halfrange:centerR(1)+halfrange,centerR(2)-halfrange:centerR(2)+halfrange);
        ucentertemp(3,j) = mean2(roimarR{j});
        ucentertemp(4,j) = mean2(roinonR{j});
        stdcentertemp(3,j) = std2(roimarR{j});
        stdcentertemp(4,j) = std2(roinonR{j});
        ubkgtemp(3,j) = mean(mar{j}(bkgmaskR));
        ubkgtemp(4,j) = mean(non{j}(bkgmaskR));
        stdbkgtemp(3,j) = std2(mar{j}(bkgmaskR));
        stdbkgtemp(4,j) = std2(non{j}(bkgmaskR));
        
%         figure;
%         th = linspace(0,pi/2,100);
%         imshow(mar{j}, 'DisplayRange',[-250 2000])
%         colorbar
%         hold on
% %         rectangle('Position',[centerL(2)-halfrange,centerL(1)-halfrange,halfrange*2,halfrange*2],'EdgeColor','r')
%         x = -maskrad(1)*cos(th) + centerL(2);
%         y = -maskrad(1)*sin(th) + centerL(1);
%         plot(x,y,'y'); axis equal;
%         x = -maskrad(2)*cos(th) + centerL(2);
%         y = -maskrad(2)*sin(th) + centerL(1);
%         plot(x,y,'y'); axis equal;
%         x = centerL(2)*ones(maskrad(2)-maskrad(1)+1,1);
%         y = centerL(1)-maskrad(2):centerL(1)-maskrad(1);
%         plot(x,y,'y')
%         x = centerL(2)-maskrad(2):centerL(2)-maskrad(1);
%         y = centerL(1)*ones(33);
%         plot(x,y,'y')
%         th = linspace(pi,pi/2,100);
% %         rectangle('Position',[centerR(2)-halfrange,centerR(1)-halfrange,halfrange*2,halfrange*2],'EdgeColor','r')
%         x = -maskrad(1)*cos(th) + centerR(2);
%         y = -maskrad(1)*sin(th) + centerR(1);
%         plot(x,y,'y'); axis equal;
%         x = -maskrad(2)*cos(th) + centerR(2);
%         y = -maskrad(2)*sin(th) + centerR(1);
%         plot(x,y,'y'); axis equal;
%         x = centerR(2)*ones(maskrad(2)-maskrad(1)+1,1);
%         y = centerR(1)-maskrad(2):centerR(1)-maskrad(1);
%         plot(x,y,'y')
%         x = centerR(2)+maskrad(1):centerR(2)+maskrad(2);
%         y = centerR(1)*ones(33);
%         plot(x,y,'y')
%         
%         figure;
%         th = linspace(0,pi/2,100);
%         imshow(non{j}, 'DisplayRange',[-250 2000])
%         colorbar
%         hold on
% %         rectangle('Position',[centerL(2)-halfrange,centerL(1)-halfrange,halfrange*2,halfrange*2],'EdgeColor','r')
%         x = -maskrad(1)*cos(th) + centerL(2);
%         y = -maskrad(1)*sin(th) + centerL(1);
%         plot(x,y,'y'); axis equal;
%         x = -maskrad(2)*cos(th) + centerL(2);
%         y = -maskrad(2)*sin(th) + centerL(1);
%         plot(x,y,'y'); axis equal;
%         x = centerL(2)*ones(maskrad(2)-maskrad(1)+1,1);
%         y = centerL(1)-maskrad(2):centerL(1)-maskrad(1);
%         plot(x,y,'y')
%         x = centerL(2)-maskrad(2):centerL(2)-maskrad(1);
%         y = centerL(1)*ones(33);
%         plot(x,y,'y')
%         th = linspace(pi,pi/2,100);
% %         rectangle('Position',[centerR(2)-halfrange,centerR(1)-halfrange,halfrange*2,halfrange*2],'EdgeColor','r')
%         x = -maskrad(1)*cos(th) + centerR(2);
%         y = -maskrad(1)*sin(th) + centerR(1);
%         plot(x,y,'y'); axis equal;
%         x = -maskrad(2)*cos(th) + centerR(2);
%         y = -maskrad(2)*sin(th) + centerR(1);
%         plot(x,y,'y'); axis equal;
%         x = centerR(2)*ones(maskrad(2)-maskrad(1)+1,1);
%         y = centerR(1)-maskrad(2):centerR(1)-maskrad(1);
%         plot(x,y,'y')
%         x = centerR(2)+maskrad(1):centerR(2)+maskrad(2);
%         y = centerR(1)*ones(33);
%         plot(x,y,'y')

        
    end

    ucentertot(:,i) = mean(ucentertemp,2);
    stdcentertot(:,i) = mean(stdcentertemp,2);
    ubkgtot(:,i) = mean(ubkgtemp,2);
    stdbkgtot(:,i) = mean(stdbkgtemp,2);
    stdbkgerr(:,i) = std(stdbkgtemp,0,2);
    ucentererr(:,i) = std(ucentertemp,0,2);
    ubkgerr(:,i) = std(ubkgtemp,0,2);
    
end

cd ../

















