% 
% COMPUTER INTEGRATED SURGERY, 600.446, Group 4
% Quantitative Assessment of Metal Artifact Reduction in C-arm Cone-Beam CT
% Guidance of Neurovascular Interventions
%
% SCRIPT sigma_artifact_onyx.m : calculates the standard deviation
% (artifact magnitude) of the background area surrounding the onyx filled
% aneurysm and the error in the standard deviation in the third constructed brain 
% phantom for images with combinations of two metal spheres. Analysis is 
% run on both the uncorrected and MAR corrected images in both noncontrast 
% water solution and contrast enhanced iodine solution for each.
%
% 
% Authors: Marta Wells <mwells20@jhu.edu> 
%          Carolina Cay-Martinez <ccaymar1@jhu.edu>
%          
% 
% Johns Hopkins University
% May 2013
%
%------------------------------------------------------------------------

clear all

fdmar = ['C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\onyx\MAR\MAR_[CORRECTED]_NON-TRUNC_NAT_FILL_HU_NORMAL_[NO_CLINICAL_U_0012';  
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\onyx\MAR\MAR_[CORRECTED]_NON-TRUNC_NAT_FILL_HU_NORMAL_[NO_CLINICAL_U_0014'];

fdnon = ['C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\onyx\MAR\MAR_[UNCORRECTED]_NON-TRUNC_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0012'; 
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\onyx\MAR\MAR_[UNCORRECTED]_NON-TRUNC_NAT_FILL_HU_NORMAL_[NO_CLINICAL_0014'];

num = length(fdmar(:,1));

stdbkgtot = zeros(2,num);
stdbkgerr = zeros(2,num);
[yy xx] = meshgrid(1:512);

center = [263,256];

findex = 180;

maskrad = [14,26];
depth = 10;

th = linspace(pi/2,-pi/2,100);

for i = 1:num
    
    stdbkgtemp = zeros(2,depth);
    
    bkgmask1 = sqrt((xx-center(1)).^2+(yy-center(2)).^2)<=maskrad(2);
    bkgmask2 = sqrt((xx-center(1)).^2+(yy-center(2)).^2)<=maskrad(1);
    bkgmask = logical(bkgmask1 - bkgmask2);
    bkgmask(:,center(2)+1:end) = 0;
    
    for j = 1:num
        cd(char(fdmar(i,:)));
        ss = ls;
        mar{j} = int16(dicomread(char(ss(findex+1+j,:))))-1024;
        cd(char(fdnon(i,:)));
        tt = ls;
        non{j} = int16(dicomread(char(tt(findex+1+j,:))))-1024;
        stdbkgtemp(1,j) = std2(mar{j}(bkgmask));
        stdbkgtemp(2,j) = std2(non{j}(bkgmask));
        
        figure; %%%Plot MAR
        imshow(mar{j},'DisplayRange',[-250 2000])
        hold on
        x = -maskrad(1)*cos(th) + center(2);
        y = -maskrad(1)*sin(th) + center(1);
        plot(x,y,'y'); axis equal;
        x = -maskrad(2)*cos(th) + center(2);
        y = -maskrad(2)*sin(th) + center(1);
        plot(x,y,'y'); axis equal;
        y = center(1)-maskrad(2):center(1)-maskrad(1);
        x = center(2)*ones(13,1);
        plot(x,y,'y'); axis equal;
        y = center(1)+maskrad(1):center(1)+maskrad(2);
        x = center(2)*ones(13,1);
        plot(x,y,'y'); axis equal;        

        
        figure; %%%Plot UC
        imshow(non{j},'DisplayRange',[-250 2000])
        hold on
        x = -maskrad(1)*cos(th) + center(2);
        y = -maskrad(1)*sin(th) + center(1);
        plot(x,y,'y'); axis equal;
        x = -maskrad(2)*cos(th) + center(2);
        y = -maskrad(2)*sin(th) + center(1);
        plot(x,y,'y'); axis equal;
        y = center(1)-maskrad(2):center(1)-maskrad(1);
        x = center(2)*ones(13,1);
        plot(x,y,'y'); axis equal;
        y = center(1)+maskrad(1):center(1)+maskrad(2);
        x = center(2)*ones(13,1);
        plot(x,y,'y'); axis equal;        

        
    end

    stdbkgtot(:,i) = mean(stdbkgtemp,2);
    stdbkgerr(:,i) = std(stdbkgtemp,0,2);
end

cd ../

    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    