% 
% COMPUTER INTEGRATED SURGERY, 600.446, Group 4
% Quantitative Assessment of Metal Artifact Reduction in C-arm Cone-Beam CT
% Guidance of Neurovascular Interventions
%
% SCRIPT sigma_artifact_spheres.m : calculates the mean attentuation 
% values of the metal coils, the mean attenutation values of the background
% area surrounding the coils, the standard deviation of the background 
% (artifact magnitude), and the error in the standard deviation in the 
% first constructed brain phantom. Analysis is run on both the uncorrected
% and MAR corrected images.
%
% 
% Authors: Marta Wells <mwells20@jhu.edu> 
%          Carolina Cay-Martinez <ccaymar1@jhu.edu>
%          
% 
% Johns Hopkins University
% May 2013
%
%------------------------------------------------------------------------

clear all

fdmar = ['C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Spheres - Leo MAR\Corrected\MAR_[CORRECTED]_DT_NON-S_NAT_FILL_HU_NORMAL_[NO_CLINICAL_US_0016';  
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Spheres - Leo MAR\Corrected\MAR_[CORRECTED]_DT_NON-S_NAT_FILL_HU_NORMAL_[NO_CLINICAL_US_0020';
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Spheres - Leo MAR\Corrected\MAR_[CORRECTED]_DT_NON-S_NAT_FILL_HU_NORMAL_[NO_CLINICAL_US_0022';
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Spheres - Leo MAR\Corrected\MAR_[CORRECTED]_DT_NON-S_NAT_FILL_HU_NORMAL_[NO_CLINICAL_US_0014';
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Spheres - Leo MAR\Corrected\MAR_[CORRECTED]_DT_NON-S_NAT_FILL_HU_NORMAL_[NO_CLINICAL_US_0017';
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Spheres - Leo MAR\Corrected\MAR_[CORRECTED]_DT_NON-S_NAT_FILL_HU_NORMAL_[NO_CLINICAL_US_0021';
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Spheres - Leo MAR\Corrected\MAR_[CORRECTED]_DT_NON-S_NAT_FILL_HU_NORMAL_[NO_CLINICAL_US_0015'
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Spheres - Leo MAR\Corrected\MAR_[CORRECTED]_DT_NON-S_NAT_FILL_HU_NORMAL_[NO_CLINICAL_US_0019';
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Spheres - Leo MAR\Corrected\MAR_[CORRECTED]_DT_NON-S_NAT_FILL_HU_NORMAL_[NO_CLINICAL_US_X020'];

fdnon = ['C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Spheres - Leo MAR\Uncorrected\MAR_[UNCORRECTED]_DT_NON-S_NAT_FILL_HU_NORMAL_[NO_CLINICAL__0016';  
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Spheres - Leo MAR\Uncorrected\MAR_[UNCORRECTED]_DT_NON-S_NAT_FILL_HU_NORMAL_[NO_CLINICAL__0020';
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Spheres - Leo MAR\Uncorrected\MAR_[UNCORRECTED]_DT_NON-S_NAT_FILL_HU_NORMAL_[NO_CLINICAL__0022';
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Spheres - Leo MAR\Uncorrected\MAR_[UNCORRECTED]_DT_NON-S_NAT_FILL_HU_NORMAL_[NO_CLINICAL__0014';
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Spheres - Leo MAR\Uncorrected\MAR_[UNCORRECTED]_DT_NON-S_NAT_FILL_HU_NORMAL_[NO_CLINICAL__0017';
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Spheres - Leo MAR\Uncorrected\MAR_[UNCORRECTED]_DT_NON-S_NAT_FILL_HU_NORMAL_[NO_CLINICAL__0021';
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Spheres - Leo MAR\Uncorrected\MAR_[UNCORRECTED]_DT_NON-S_NAT_FILL_HU_NORMAL_[NO_CLINICAL__0015'
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Spheres - Leo MAR\Uncorrected\MAR_[UNCORRECTED]_DT_NON-S_NAT_FILL_HU_NORMAL_[NO_CLINICAL__0019';
'C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\Spheres - Leo MAR\Uncorrected\MAR_[UNCORRECTED]_DT_NON-S_NAT_FILL_HU_NORMAL_[NO_CLINICAL__X020'];


%% 1. 16 - 3.2mm Titanium
%% 2. 20 - 6.4mm Titanium
%% 3. 22 - 12.8mm Titanium
%% 4. 14 - 3.2mm Steel
%% 5. 17 - 6.4mm Steel
%% 6. 21 - 12.8mm Steel
%% 7. 15 - 3.2mm Tungsten
%% 8. 19 - 6.4mm Tungsten
%% 9. 20x - 12.8mm Tungsten

num = length(fdmar(:,1));

ucentertot = zeros(2,num);
ucentererr = zeros(2,num);
stdcentertot = zeros(2,num);
ubkgtot = zeros(2,num);
ubkgerr = zeros(2,num);
stdbkgtot = zeros(2,num);
stdbkgerr = zeros(2,num);
[yy xx] = meshgrid(1:512);

centers = [277,233;
    292,228;
    285,231;
    295,229;
    289,229;
    292,229;
    296,218;
    288,233;
    357,242];

fst = [152;
    168;
    152;
    162;
    154;
    169;
    174;
    163;
    255];

maskrad = [13,33;16,34;23,38;13,33;16,34;23,38;13,33;16,34;23,38];  %%% Bkg ROI radius: small - 20, medium - 18, large - 15 for ~1450 pixels each
depth = [4;8;16;4;8;16;4;8;16];
halfrange = [2;4;7;2;4;7;2;4;7;];    %%% Center ROI: small - 5x5x4, medium - 9x9x8, large - 15x15x16

for i  = 1:num
    ucentertemp = zeros(2,depth(i));
    stdcentertemp = zeros(2,depth(i));
    ubkgtemp = zeros(2,depth(i));
    stdbkgtemp = zeros(2,depth(i));
    center = centers(i,:);
    findex = fst(i);
    
    bkgmask1 = sqrt((xx-center(1)).^2+(yy-center(2)).^2)<=maskrad(i,2);
    bkgmask2 = sqrt((xx-center(1)).^2+(yy-center(2)).^2)<=maskrad(i,1);
    bkgmask = logical(bkgmask1 - bkgmask2);
    bkgmask(:,center(2)+1:end) = 0;
    
    for j = 1:depth(i)
        cd(char(fdmar(i,:)));
        ss = ls;
        mar{j} = int16(dicomread(char(ss(findex+1+j,:))))-1024;
        cd(char(fdnon(i,:)));
        tt = ls;
        non{j} = int16(dicomread(char(tt(findex+1+j,:))))-1024;
        roimar{j} = mar{j}(center(1)-halfrange(i):center(1)+halfrange(i),center(2)-halfrange(i):center(2)+halfrange(i));
        roinon{j} = non{j}(center(1)-halfrange(i):center(1)+halfrange(i),center(2)-halfrange(i):center(2)+halfrange(i));
        ucentertemp(1,j) = mean2(roimar{j});
        ucentertemp(2,j) = mean2(roinon{j});
        stdcentertemp(1,j) = std2(roimar{j});
        stdcentertemp(2,j) = std2(roinon{j});
        ubkgtemp(1,j) = mean(mar{j}(bkgmask));
        ubkgtemp(2,j) = mean(non{j}(bkgmask));
        stdbkgtemp(1,j) = std2(mar{j}(bkgmask));
        stdbkgtemp(2,j) = std2(non{j}(bkgmask));
    end

    ucentertot(:,i) = mean(ucentertemp,2);
    stdcentertot(:,i) = mean(stdcentertemp,2);
    ubkgtot(:,i) = mean(ubkgtemp,2);
    stdbkgtot(:,i) = mean(stdbkgtemp,2);
    stdbkgerr(:,i) = std(stdbkgtemp,0,2);
    ucentererr(:,i) = std(ucentertemp,0,2);
    ubkgerr(:,i) = std(ubkgtemp,0,2);
    
end

cd ../../

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% 18 - Control
% 
% [yy xx] = meshgrid(1:512);
% center = [275,212];
% findex = [160,97];
% stdbkgcontrol = zeros(2,10);
% 
% cd('C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\MARproject\MAR_CORRECTED_18');
% ss = ls;
% 
% for j = 1:10
%     marcontrol{j} = dicomread(char(ss(findex(2)+1+j,:)));
%     roimarcontrol{j} = marcontrol{j}(center(1)-20:center(1)+20,center(2)-20:center(2)+20);
%     stdbkgcontrol(1,j) = std2(roimarcontrol{j});
% end
% 
% cd('C:\Users\mwells20\Documents\2012-2013\Spring 2013\CIS2\MARproject\NEW_CALIBRATION_NAT_FILL_HU_NORMAL_[INSPACE3D]_0018');
% tt = ls;
% 
% for j = 1:10
%     noncontrol{j} = dicomread(char(tt(findex(1)+1+j,:)));
%     roinoncontrol{j} = noncontrol{j}(center(1)-20:center(1)+20,center(2)-20:center(2)+20);
%     stdbkgcontrol(2,j) = std2(roinoncontrol{j});
% end
% 
% stdbkgcontrolerr = std(stdbkgcontrol,0,2);
% stdbkgcontrol = mean(stdbkgcontrol,2);
% 
% cd ../

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




























