% 
% COMPUTER INTEGRATED SURGERY, 600.446, Group 4
% Quantitative Assessment of Metal Artifact Reduction in C-arm Cone-Beam CT
% Guidance of Neurovascular Interventions
%
% FUNCTION spheres_surfacearea.m : calculates the surface area of a binary
% volume through convolution to count the exposed faces of each voxel.
%
% Inputs: a binary volume matrix representing the object
% 
% Outputs: the total exposed surface area of the object
%
% Authors: Marta Wells <mwells20@jhu.edu> 
%          Carolina Cay-Martinez <ccaymar1@jhu.edu>
%          
% 
% Johns Hopkins University
% May 2013
%
%------------------------------------------------------------------------

function [surfacearea] = spheres_surfacearea(img)

conn6Kernel = zeros([3,3,3]);
conn6Kernel(2,2,1) = 1;
conn6Kernel(1,2,2) = 1;
conn6Kernel(2,1,2) = 1;
conn6Kernel(2,3,2) = 1;
conn6Kernel(3,2,2) = 1;
conn6Kernel(2,2,3) = 1;

sumOfFaces = convn(img, conn6Kernel, 'same');
surfaceArea = 6 * img - sumOfFaces;

 surfaceArea(surfaceArea<0) = 0;
 
 binaryVolume = surfaceArea > 0;
cc = bwconncomp(binaryVolume, 6);

measurements = regionprops(cc, surfaceArea, 'PixelValues');

numberOfRegions = length(measurements);
surfacearea = 0;

for k = 1 : numberOfRegions
    thesePixelValues = [measurements(k).PixelValues];
    surfacearea = sum(thesePixelValues)+surfacearea;
end
















